#include "DS1307.h"

/***************************************************

Function To Read Internal Registers of DS1307
---------------------------------------------

address : Address of the register
data: value of register is copied to this.


Returns:
0= Failure
1= Success
***************************************************/

uint8_t DS1307Read(uint8_t address,uint8_t *data)
{
	uint8_t res;	//result
	
	//Start
	I2CStart();
	
	//SLA+W (for dummy write to set register pointer)
	res=I2CWriteByte(0b11010000);	//DS1307 address + W
	
	//Error
	if(!res)	return FALSE;
	
	//Now send the address of required register
	res=I2CWriteByte(address);
	
	//Error
	if(!res)	return FALSE;
	
	//Repeat Start
	I2CStart();
	
	//SLA + R
	res=I2CWriteByte(0b11010001);	//DS1307 Address + R
	
	//Error
	if(!res)	return FALSE;
	
	//Now read the value with NACK
	res=I2CReadByte(data,0);
	
	//Error
	if(!res)	return FALSE;
	
	//STOP
	I2CStop();
	
	return TRUE;
}

/***************************************************

Function To Write Internal Registers of DS1307
---------------------------------------------

address : Address of the register
data: value to write.


Returns:
0= Failure
1= Success
***************************************************/

uint8_t DS1307Write(uint8_t address,uint8_t data)
{
	uint8_t res;	//result
	
	//Start
	I2CStart();
	
	//SLA+W
	res=I2CWriteByte(0b11010000);	//DS1307 address + W
	
	//Error
	if(!res)	return FALSE;
	
	//Now send the address of required register
	res=I2CWriteByte(address);
	
	//Error
	if(!res)	return FALSE;
	
	//Now write the value
	res=I2CWriteByte(data);
	
	//Error
	if(!res)	return FALSE;
	
	//STOP
	I2CStop();
	
	return TRUE;
}
	


void put_time(unsigned char x, unsigned char y)
{
	unsigned char temp;

	unsigned char sek[2];
	unsigned char min[2];
	unsigned char std[2];
	unsigned char wtg;
	unsigned char tag[2];
	unsigned char mon[2];
	unsigned char yea[2];
	
	DS1307Read(0x02, &temp);
	_delay_ms(1);
	std[0] = (temp & 0xF0)>>4;
	std[1] = temp & 0x0F;
	
	DS1307Read(0x01, &temp);
	_delay_ms(1);
	min[0] = (temp & 0xF0)>>4;
	min[1] = temp & 0x0F;

	DS1307Read(0x00, &temp);
	_delay_ms(1);
	sek[0] = (temp & 0xF0)>>4;
	sek[1] = temp & 0x0F;

	DS1307Read(0x03, &temp);
	_delay_ms(1);
	wtg = temp;

	DS1307Read(0x04, &temp);
	_delay_ms(1);
	tag[0] = (temp & 0xF0)>>4;
	tag[1] = temp & 0x0F;

	DS1307Read(0x05, &temp);
	_delay_ms(1);
	mon[0] = (temp & 0xF0)>>4;
	mon[1] = temp & 0x0F;

	DS1307Read(0x06, &temp);
	_delay_ms(1);
	yea[0] = (temp & 0xF0)>>4;
	yea[1] = temp & 0x0F;
	
	put_char(std[0] + 48, x, y, font_6x8);
	put_char(std[1] + 48, x + 6, y, font_6x8);

	put_char(':', x + 12, y, font_6x8);

	put_char(min[0] + 48, x + 18, y, font_6x8);
	put_char(min[1] + 48, x + 24, y, font_6x8);

	put_char(':', x + 30, y, font_6x8);

	put_char(sek[0] + 48, x + 36, y, font_6x8);
	put_char(sek[1] + 48, x + 42, y, font_6x8);
	/*
	switch(wtg)
	{
		case 0:
			put_string("Sonntag", 0, 20, font_12x16);
		break;

		case 1:
			put_string("Montag", 0, 20, font_12x16);
		break;

		case 2:
			put_string("Dienstag", 0, 20, font_12x16);
		break;

		case 3:
			put_string("Mittwoch", 0, 20, font_12x16);
		break;

		case 4:
			put_string("Donnerstag", 0, 20, font_12x16);
		break;

		case 5:
			put_string("Freitag", 0, 20, font_12x16);
		break;

		case 6:
			put_string("Samstag", 0, 20, font_12x16);
		break;
	}


	put_char(tag[0] + 48, 0, 40, font_12x16);
	put_char(tag[1] + 48, 12, 40, font_12x16);

	put_char('/', 24, 40, font_12x16);

	put_char(mon[0] + 48, 36, 40, font_12x16);
	put_char(mon[1] + 48, 48, 40, font_12x16);

	put_char('/', 60, 40, font_12x16);

	put_char(yea[0] + 48, 72, 40, font_12x16);
	put_char(yea[1] + 48, 84, 40, font_12x16);
	*/

}

